<?php
/*
 * Author: Etienne Gauthier (etienne_sf@sourceforge.net)
 * 
 * This page manages the upload http request. Its aim is to:
 * - Add the uploaded files into the database
 * - Calculate the thumb and normal picture.
 * - return a status to the applet, by writting one simple line. This return is:
 *     SUCCESS               (if everything is Ok)
 *     ERROR: Error message  (if some problem occurs)
 */

if (!defined('IN_COPPERMINE')) { die('Not in Coppermine...');}
if (!defined('JUPLOAD_PHP')) { die('Not in Jupload...');}

define('JUPLOAD_PHP_in_upload_picture', true);


$return = "Unknow return status";

//We don't want ths cpg_die to be called. Instead, we want just the error in the script ouptut.
//see jupload_cpg_die for more informations
$callCpgDie = false;

require('plugins/jupload/include/j_picmgmt.inc.php');

//If the user may not upload pictures, there is no reason for him to go on this page.
//USER_CAN_CREATE_ALBUMS: seems to indicate that the user may have its personnal gallery (at least for the admin)
if (!USER_CAN_UPLOAD_PICTURES && !USER_CAN_CREATE_ALBUMS) {
	$msg = str_replace('$1', 'login.php?referer=plugins/jupload/jupload.php', $lang_jupload_php['perm_denied']);

	cpg_die(ERROR, $msg, __FILE__, __LINE__);
}


//####################################################################################################
//#################################  MAIN CODE BLOC  #################################################
//####################################################################################################

//The response in the HTTP body may be read by the applet and displayed to the user. It isn't HTML
//This is especially right for error codes. I force them to UTF-8:
header("Content-Type: text/plain; charset=UTF-8"); 

//Some tries around character encoding
//echo("encoding test: " . rawurlencode(mb_convert_encoding("ê", "UTF-8")) . "\r\n"); //Ok.

/*
	echo("ERROR: test encoding -éèà-");
	//echo(mb_convert_encoding("éèà", "UTF-8"));
	echo $lang_errors['quota_exceeded'];
	echo("-\r\n");
*/

//From time to time, probably depending on various factor, the applet receives no return from the server.
//Let's write at least one line, to be sure that the server will (should) answer something.
echo("Within upload_picture.php\r\n");

//Note: 
// When in chunk mode, Coppermine controls the size of the last chunk, and not the size of the whole uploaded
//file, that may have been split into several chunk.

//If the maxFileSize is defined in the Jupload configuration, it overrides the Coppermine configuration
if ($JUPLOAD_CONFIG['maxNonTransformedPictureSize'] > 0) {
	$CONFIG['max_upl_size'] = $JUPLOAD_CONFIG['maxNonTransformedPictureSize'];
}

//Let's read the _FILES array. What to do, depend on the script parameters: is the file sent in one piece, 
//or in several chunks.
handle_uploaded_files('userpicture');
//echo($escrow_array[0]['actual_name'] . "\r\n");
//echo($escrow_array[0]['temporary_name'] . "\r\n");


if (count($escrow_array) > 1) {
	echo ("ERROR: too many files uploaded (" . count($escrow_array) . ")\r\n");
} else if (count($escrow_array) == 0) {
	//What's up doc ?
	$error_reason = '';
	if (count($file_failure_array) > 0) {
		//Ok, we have some news of the error in this array
		$error_reason = '(' . $file_failure_array[0]['failure_ordinal']
			. ', ' . $file_failure_array[0]['file_name']
			. ', ' . $file_failure_array[0]['error_code']
			. ' )';
	}
	echo ('ERROR: no file uploaded (' . $error_reason . ")\r\n");
} else if (!$chunkedUpload  ||  ($chunkedUpload && $jufinal)) {
	//Ok, one file has been uploaded. So, we are in one of these two cases:
	//a) Non-chunk upload (that is: standard upload)
	//b) Chunk upload (that is: the file is sent by pieces), and we just received the last chunk.


	//Let's read the given parameters.	
    $title = addslashes($_POST['title']);
    $caption = addslashes($_POST['caption']);
    $keywords = addslashes($_POST['keywords']);
    $user1 = addslashes($_POST['user1']);
    $user2 = addslashes($_POST['user2']);
    $user3 = addslashes($_POST['user3']);
    $user4 = addslashes($_POST['user4']);
    // Capture movie or audio width and height if sent.
    $movie_wd = isset($_POST['movie_wd']) ? (int)$_POST['movie_wd'] : 320;
    $movie_ht = isset($_POST['movie_ht']) ? (int)$_POST['movie_ht'] : 240;
    
	//We then add the file to the Coppermine database
	$actual_name = $escrow_array[0]['actual_name'];
	$urlencode_actual_name = urlencode($actual_name);
	$rawurlencode_actual_name = rawurlencode($actual_name);
	//$actual_name_encoded = mb_convert_encoding($actual_name, "UTF-8", "US-ASCII");
	echo("[INFO] Internal encoding: " . mb_internal_encoding() . "\n");
	//KO: generate unknown character (transfomed in a ?)$actual_name_encoded = mb_convert_encoding($actual_name, "US-ASCII", "UTF-8");
	echo("-DEBUG- [upload_picture.php] Before call to jupload_add_physical_file for $actual_name " .
			"(urlencode: $urlencode_actual_name, rawurlencode: $rawurlencode_actual_name, " . 
			"actual_name_encoded: $actual_name_encoded).\r\n");
	$file_placement = jupload_add_physical_file($album, $actual_name, $escrow_array[0]['temporary_name'],
		$title, $caption, $keywords, $user1, $user2, $user3, $user4, $category, $raw_ip, $hdr_ip, $movie_wd, $movie_ht);
	echo("-DEBUG- [upload_picture.php] After call to jupload_add_physical_file for $actual_name " .
			"(urlencode: $urlencode_actual_name, rawurlencode: $rawurlencode_actual_name).\r\n");

	//If we received an error, we transmit it, and return.	
	if (substr($file_placement, 0, 7) == 'ERROR: ') {
		echo(strip_tags($file_placement) . "1\r\n");
	} else if ($ERROR != ''){
		echo('ERROR: ' . strip_tags($ERROR) . "2\r\n");
	} else if ($file_placement == 'no1' || $file_placement == 'no2') {
		echo('ERROR: ' . strip_tags($lang_upload_php['no_place']) . " 3 (file_placement: $file_placement)\r\n");
	} else if ($file_placement == 'yes') {
		if ($PIC_NEED_APPROVAL) {
			echo("SUCCESS\r\nNEED APPROVAL\r\n");
		} else {
			//ob_end_flush();
			//ob_start("", 2);
			echo("SUCCESS\r\n");
		}
		//Send a mail, if needed.
		after_upload();
	} else {
		echo("WARNING: Unknown placement status (file_placement=$file_placement)\r\n");
	}
} else {
	//If we come here, we are in chunk mode, but we didn't receive the last one.
	echo("Chunk $jupart received\r\nSUCCESS\r\n");
}
/* */
echo("End of upload_picture.php\r\n");
